==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/da-DK/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Brugerdefinerede felter',
    'manage'                    => 'Administrer',
    'field'		                => 'Felt',
    'about_fieldsets_title'		=> 'Om Feltsæt',
    'about_fieldsets_text'		=> 'Feltsæt giver dig mulighed for at oprette grupper af brugerdefinerede felter, der ofte genbruges til specifikke asset-modeltyper.',
    'custom_format'             => 'Tilpasset Regex format...',
    'encrypt_field'      	        => 'Kryptere værdien af dette felt i databasen',
    'encrypt_field_help'      => 'Advarsel: Kryptere et felt gør det uransagelige.',
    'encrypted'      	        => 'Krypteret',
    'fieldset'      	        => 'Feltsæt',
    'qty_fields'      	      => 'Antal felter',
    'fieldsets'      	        => 'Feltsæt',
    'fieldset_name'           => 'Feltsættets navn',
    'field_name'              => 'Feltnavn',
    'field_values'            => 'Feltværdier',
    'field_values_help'       => 'Tilføj valgbare indstillinger, en pr. Linje. Andre linjer end den første linje vil blive ignoreret.',
    'field_element'           => 'Form-elementet',
    'field_element_short'     => 'Element',
    'field_format'            => 'Format',
    'field_custom_format'     => 'Brugerdefineret Format',
    'field_custom_format_help'     => 'Dette felt muliggør anvendelse af et regex-udtryk til validering. Det skal starte med "regex:" - for f.eks. at validere, at en tilpasset feltværdi indeholder et gyldig IMEI (15 numeriske cifre), vil du skulle benytte <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'Påkrævet',
    'req'   		              => 'Req.',
    'used_by_models'   		    => 'Bruges af modeller',
    'order'   		            => 'Ordre',
    'create_fieldset'         => 'Nyt Feltsæt',
    'update_fieldset'         => 'Opdater Feltsæt',
    'fieldset_does_not_exist'   => 'Feltsæt :id findes ikke',
    'fieldset_updated'         => 'Feltsæt opdateret',
    'create_fieldset_title' => 'Opret et nyt feltsæt',
    'create_field'            => 'Nyt Brugerdefinerede Felt',
    'create_field_title' => 'Opret et nyt brugerdefineret felt',
    'value_encrypted'      	        => 'Værdien af dette felt er krypteret i databasen. Kun admins vil være i stand til at se den krypteret værdi',
    'show_in_email'     => 'Inkludér værdien af ​​dette felt i tjekud-e-mail til brugeren? Krypterede felter kan ikke medtages i e-mails',
    'show_in_email_short'     => 'Inkluder i e-mails.',
    'help_text' => 'Hjælp Tekst',
    'help_text_description' => 'Dette er valgfri tekst, der vises under formelementerne, mens du redigerer et aktiv for at give kontekst på feltet.',
    'about_custom_fields_title' => 'Om Brugerdefinerede Felter',
    'about_custom_fields_text' => 'Brugerdefinerede felter giver dig mulighed for at tilføje vilkårlige attributter til aktiver.',
    'add_field_to_fieldset' => 'Tilføj felt til feltsæt',
    'make_optional' => 'Påkrævet - klik for at gøre valgfri',
    'make_required' => 'Valgfri - klik for at gøre påkrævet',
    'reorder' => 'Genbestil',
    'db_field' => 'DB Felt',
    'db_convert_warning' => 'ADVARSEL. Dette felt er i tabellen brugerdefinerede felter som <code>:db_column</code> men bør være <code>:expected</code>.',
    'is_unique' => 'Denne værdi skal være unik for alle aktiver',
    'unique' => 'Unik',
    'display_in_user_view' => 'Tillad brugeren at se disse værdier i deres visning Tildelte aktiver side',
    'display_in_user_view_table' => 'Synlig for bruger',
    'auto_add_to_fieldsets' => 'Tilføj automatisk dette til alle nye feltsæt',
    'add_to_preexisting_fieldsets' => 'Tilføj til eksisterende feltsæt',
    'show_in_listview' => 'Vis som standard i listevisninger. Autoriserede brugere vil stadig kunne vise/skjule via kolonnevælgeren',
    'show_in_listview_short' => 'Vis i lister',
    'show_in_requestable_list_short' => 'Vis i liste over anfordringsberettigede aktiver',
    'show_in_requestable_list' => 'Vis værdi i liste over anfordringsaktiver. Krypterede felter vil ikke blive vist',
    'encrypted_options' => 'Dette felt er krypteret, så nogle visningsindstillinger vil ikke være tilgængelige.',

];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/da-DK/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Brugerdefinerede felter',
    'manage'                    => 'Administrer',
    'field'		                => 'Felt',
    'about_fieldsets_title'		=> 'Om Feltsæt',
    'about_fieldsets_text'		=> 'Feltsæt giver dig mulighed for at oprette grupper af brugerdefinerede felter, der ofte genbruges til specifikke asset-modeltyper.',
    'custom_format'             => 'Tilpasset Regex format...',
    'encrypt_field'      	        => 'Kryptere værdien af dette felt i databasen',
    'encrypt_field_help'      => 'Advarsel: Kryptere et felt gør det uransagelige.',
    'encrypted'      	        => 'Krypteret',
    'fieldset'      	        => 'Feltsæt',
    'qty_fields'      	      => 'Antal felter',
    'fieldsets'      	        => 'Feltsæt',
    'fieldset_name'           => 'Feltsættets navn',
    'field_name'              => 'Feltnavn',
    'field_values'            => 'Feltværdier',
    'field_values_help'       => 'Tilføj valgbare indstillinger, en pr. Linje. Andre linjer end den første linje vil blive ignoreret.',
    'field_element'           => 'Form-elementet',
    'field_element_short'     => 'Element',
    'field_format'            => 'Format',
    'field_custom_format'     => 'Brugerdefineret Format',
    'field_custom_format_help'     => 'Dette felt muliggør anvendelse af et regex-udtryk til validering. Det skal starte med "regex:" - for f.eks. at validere, at en tilpasset feltværdi indeholder et gyldig IMEI (15 numeriske cifre), vil du skulle benytte <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'Påkrævet',
    'req'   		              => 'Req.',
    'used_by_models'   		    => 'Bruges af modeller',
    'order'   		            => 'Ordre',
    'create_fieldset'         => 'Nyt Feltsæt',
    'update_fieldset'         => 'Opdater Feltsæt',
    'fieldset_does_not_exist'   => 'Feltsæt :id findes ikke',
    'fieldset_updated'         => 'Feltsæt opdateret',
    'create_fieldset_title' => 'Opret et nyt feltsæt',
    'create_field'            => 'Nyt Brugerdefinerede Felt',
    'create_field_title' => 'Opret et nyt brugerdefineret felt',
    'value_encrypted'      	        => 'Værdien af dette felt er krypteret i databasen. Kun admins vil være i stand til at se den krypteret værdi',
    'show_in_email'     => 'Inkludér værdien af ​​dette felt i tjekud-e-mail til brugeren? Krypterede felter kan ikke medtages i e-mails',
    'show_in_email_short' => 'Inkluder i e-mails',
    'help_text' => 'Hjælp Tekst',
    'help_text_description' => 'Dette er valgfri tekst, der vises under formelementerne, mens du redigerer et aktiv for at give kontekst på feltet.',
    'about_custom_fields_title' => 'Om Brugerdefinerede Felter',
    'about_custom_fields_text' => 'Brugerdefinerede felter giver dig mulighed for at tilføje vilkårlige attributter til aktiver.',
    'add_field_to_fieldset' => 'Tilføj felt til feltsæt',
    'make_optional' => 'Påkrævet - klik for at gøre valgfri',
    'make_required' => 'Valgfri - klik for at gøre påkrævet',
    'reorder' => 'Genbestil',
    'db_field' => 'DB Felt',
    'db_convert_warning' => 'ADVARSEL. Dette felt er i tabellen brugerdefinerede felter som <code>:db_column</code> men bør være <code>:expected</code>.',
    'is_unique' => 'Denne værdi skal være unik for alle aktiver',
    'unique' => 'Unik',
    'display_in_user_view' => 'Tillad brugeren at se disse værdier i deres visning Tildelte aktiver side',
    'display_in_user_view_table' => 'Synlig for bruger',
    'auto_add_to_fieldsets' => 'Tilføj automatisk dette til alle nye feltsæt',
    'add_to_preexisting_fieldsets' => 'Tilføj til eksisterende feltsæt',
    'show_in_listview' => 'Vis som standard i listevisninger. Autoriserede brugere vil stadig kunne vise/skjule via kolonnevælgeren',
    'show_in_listview_short' => 'Vis i lister',
    'show_in_requestable_list_short' => 'Vis i liste over anfordringsberettigede aktiver',
    'show_in_requestable_list' => 'Vis værdi i liste over anfordringsaktiver. Krypterede felter vil ikke blive vist',
    'encrypted_options' => 'Dette felt er krypteret, så nogle visningsindstillinger vil ikke være tilgængelige.',
    'display_checkin' => 'Display in checkin forms',
    'display_checkout' => 'Display in checkout forms',

];
